colour.models.dataset.aces_rgb Module — Colour 0.3.0 documentation

# colour.models.dataset.aces_rgb Module

## ACES RGB Colourspace

Defines the ACES RGB colourspace and its variations:

- `ACES_RGB_COLOURSPACE`
- `ACES_RGB_LOG_COLOURSPACE`
- `ACES_RGB_PROXY_10_COLOURSPACE`
- `ACES_RGB_PROXY_12_COLOURSPACE`

See also

RGB Colourspaces IPython Notebook

References

[1] | http://www.oscars.org/science-technology/council/projects/aces.html (Last accessed 24 February 2014)

[2] | http://www.dropbox.com/sh/iwd09buudm3lfod/gyjDF-k7oC/ACES_v1.0.1.pdf (Last accessed 24 February 2014)

`colour.models.dataset.aces_rgb.` `ACES_RGB_PRIMARIES` = array([[ 7.34700000e-01, 2.65300000e-01], [ 0.00000000e+00, 1.00000000e+00], [ 1.00000000e-04, -7.70000000e-02]])

  ACES RGB colourspace primaries.

  ACES_RGB_PRIMARIES : ndarray, (3, 2)

  References

  [3] | http://www.dropbox.com/sh/iwd09buudm3lfod/gyjDF-k7oC/ACES_v1.0.1.pdf: 4.1.2 Color space chromaticities (Last accessed 24 February 2014)

`colour.models.dataset.aces_rgb.` `ACES_RGB_WHITEPOINT` = (0.32168, 0.33767)

  ACES RGB colourspace whitepoint.

  ACES_RGB_WHITEPOINT : tuple

`colour.models.dataset.aces_rgb.` `ACES_RGB_TO_XYZ_MATRIX` = array([[ 9.52552396e-01, 0.00000000e+00, 9.36786317e-05], [ 3.43966450e-01, 7.28166097e-01, -7.21325464e-02], [ 0.00000000e+00, 0.00000000e+00, 1.00882518e+00]])

  ACES RGB colourspace to CIE XYZ colourspace matrix.

  ACES_RGB_TO_XYZ_MATRIX : array_like, (3, 3)

  References

  [4] | http://www.dropbox.com/sh/iwd09buudm3lfod/gyjDF-k7oC/ACES_v1.0.1.pdf: 4.1.4 Converting ACES RGB values to CIE XYZ values (Last accessed 24 February 2014)

`colour.models.dataset.aces_rgb.` `XYZ_TO_ACES_RGB_MATRIX` = array([[ 1.04981102e+00, 0.00000000e+00, -9.74845410e-05], [ -4.95903023e-01, 1.37331305e+00, 9.82400365e-02], [ 0.00000000e+00, 0.00000000e+00, 9.91252022e-01]])

  CIE XYZ colourspace to ACES RGB colourspace matrix.

  XYZ_TO_ACES_RGB_MATRIX : array_like, (3, 3)

`colour.models.dataset.aces_rgb.` `ACES_RGB_TRANSFER_FUNCTION`(x)

  Transfer function from linear to ACES RGB colourspace.

  ACES_RGB_TRANSFER_FUNCTION : object

`colour.models.dataset.aces_rgb.` `ACES_RGB_INVERSE_TRANSFER_FUNCTION`(x)

  Inverse transfer function from ACES RGB colourspace to linear.

  ACES_RGB_INVERSE_TRANSFER_FUNCTION : object

`colour.models.dataset.aces_rgb.` `ACES_RGB_COLOURSPACE` = <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e12350>

  ACES RGB colourspace.

  ACES_RGB_COLOURSPACE : RGB_Colourspace

`colour.models.dataset.aces_rgb.` `ACES_RGB_LOG_CONSTANTS` = {'denorm_trans': 3.0517578125e-05, 'log_xperstop': 2048, 'log_unity': 32768, 'denorm_fake0': 1.52587890625e-05}

  ACES RGB Log colourspace constants.

  ACES_RGB_LOG_CONSTANTS : Structure

`colour.models.dataset.aces_rgb.` `ACES_RGB_LOG_TRANSFER_FUNCTION`(value, is_16_bit_integer=False)

  Transfer function from linear to ACES RGB Log colourspace.

  ACES_RGB_LOG_TRANSFER_FUNCTION : object

`colour.models.dataset.aces_rgb.` `ACES_RGB_LOG_INVERSE_TRANSFER_FUNCTION`(value)

  Inverse transfer function from ACES RGB Log colourspace to linear.

  ACES_RGB_LOG_INVERSE_TRANSFER_FUNCTION : object

`colour.models.dataset.aces_rgb.` `ACES_RGB_LOG_COLOURSPACE` = <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e12390>

  ACES RGB Log colourspace.

  ACES_RGB_LOG_COLOURSPACE : RGB_Colourspace

  References

  [5] | Logarithmic Encoding of ACES Data for use within Color Grading Systems (Last accessed 17 May 2014)

`colour.models.dataset.aces_rgb.` `ACES_RGB_PROXY_10_CONSTANTS` = {'CV_min': 0, 'steps_per_stop': 50, 'mid_CV_offset': 425, 'CV_max': 1023, 'mid_log_offset': -2.5}

  ACES RGB Proxy 10 colourspace constants.

  ACES_RGB_PROXY_10_CONSTANTS : Structure

`colour.models.dataset.aces_rgb.` `ACES_RGB_PROXY_12_CONSTANTS` = {'CV_min': 0, 'steps_per_stop': 200, 'mid_CV_offset': 1700, 'CV_max': 4095, 'mid_log_offset': -2.5}

  ACES RGB Proxy 12 colourspace constants.

  ACES_RGB_PROXY_12_CONSTANTS : Structure

`colour.models.dataset.aces_rgb.` `ACES_RGB_PROXY_CONSTANTS` = CaseInsensitiveMapping({u'12 Bit': {'CV_min': 0, 'steps_per_stop': 200, 'mid_CV_offset': 1700, 'CV_max': 4095, 'mid_log_offset': -2.5}, u'10 Bit': {'CV_min': 0, 'steps_per_stop': 50, 'mid_CV_offset': 425, 'CV_max': 1023, 'mid_log_offset': -2.5}})

  Aggregated ACES RGB Proxy colourspace constants.

  ACES_RGB_PROXY_CONSTANTS : dict
    (‘10 Bit’, ‘12 Bit’)

`colour.models.dataset.aces_rgb.` `ACES_RGB_PROXY_10_TRANSFER_FUNCTION`(x)

  Transfer function from linear to ACES RGB Proxy 10 colourspace.

  ACES_RGB_PROXY_10_TRANSFER_FUNCTION : object

`colour.models.dataset.aces_rgb.` `ACES_RGB_PROXY_10_INVERSE_TRANSFER_FUNCTION`(x)

  Inverse transfer function from ACES RGB Proxy 10 colourspace to linear.

  ACES_RGB_PROXY_10_INVERSE_TRANSFER_FUNCTION : object

`colour.models.dataset.aces_rgb.` `ACES_RGB_PROXY_12_TRANSFER_FUNCTION`(x)

  Transfer function from linear to ACES RGB Proxy 12 colourspace.

  ACES_RGB_PROXY_12_TRANSFER_FUNCTION : object

`colour.models.dataset.aces_rgb.` `ACES_RGB_PROXY_12_INVERSE_TRANSFER_FUNCTION`(x)

  Inverse transfer function from ACES RGB Proxy 12 colourspace to linear.

  ACES_RGB_PROXY_12_INVERSE_TRANSFER_FUNCTION : object

`colour.models.dataset.aces_rgb.` `ACES_RGB_PROXY_10_COLOURSPACE` = <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e124d0>

  ACES RGB Proxy 10 colourspace.

  ACES_RGB_PROXY_10_COLOURSPACE : RGB_Colourspace

  References

  [6] | ACESproxy, an Integer Log Encoding of ACES Image Data (Last accessed 17 May 2014)

`colour.models.dataset.aces_rgb.` `ACES_RGB_PROXY_12_COLOURSPACE` = <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e12510>

  ACES RGB Proxy 12 colourspace.

  ACES_RGB_PROXY_12_COLOURSPACE : RGB_Colourspace

  References

  [6] | ACESproxy, an Integer Log Encoding of ACES Image Data (Last accessed 17 May 2014)